.. ArchiveTeam Seesaw Kit documentation master file, created by
   sphinx-quickstart on Fri Nov 15 22:56:31 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ArchiveTeam Seesaw Kit's documentation!
==================================================

Contents:

.. toctree::
   :maxdepth: 2

   api/seesaw


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

